==> ultracopier_2.2.4.7.orig.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/it/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="328"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Acquista versione ultimate per finanziare lo sviluppo</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="328"/>
        <source>Register your key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="427"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>File %1/%2, dimensione: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="661"/>
        <source>Copy list</source>
        <translation>Lista di copia</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="663"/>
        <source>Move list</source>
        <translation>Lista di spostamento</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1091"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Non chiudere se vengono trovati errori</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1092"/>
        <source>Never close</source>
        <translation>Non chiudere mai</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1093"/>
        <source>Always close</source>
        <translation>Chiudere sempre</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1095"/>
        <source>File Name, 0KB</source>
        <translation>Nome file, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1289"/>
        <location filename="../../interface.cpp" line="1301"/>
        <location filename="../../interface.cpp" line="1313"/>
        <source>Select a color</source>
        <translation>Selezionare colore</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1388"/>
        <location filename="../../interface.cpp" line="1392"/>
        <location filename="../../interface.cpp" line="1394"/>
        <source>%1 %2% of %3</source>
        <translation>%1 %2% di %3</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="284"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Non chiudere se vengono rilevati errori</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="285"/>
        <source>Never close</source>
        <translation>Non chiudere mai</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="286"/>
        <source>Always close</source>
        <translation>Chiudere sempre</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="482"/>
        <location filename="../../ThemesFactory.cpp" line="497"/>
        <location filename="../../ThemesFactory.cpp" line="512"/>
        <source>Select a color</source>
        <translation>Selezionare colore</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>From:</source>
        <translation>Da:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="74"/>
        <source>To:</source>
        <translation>A:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="235"/>
        <source>&amp;More</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="255"/>
        <source>&amp;Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="269"/>
        <source>&amp;Skip</source>
        <translation>Salta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="280"/>
        <source>&amp;Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="127"/>
        <source>Close on transfer completion</source>
        <translation>Chiudi a trasferimento completato</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="295"/>
        <source>Limit copy speed to:</source>
        <translation>Limitare velocità di copia a:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="338"/>
        <source>Transfer list</source>
        <translation>Lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="361"/>
        <source>Move the selected items to the top</source>
        <translation>Metti elementi selezionati in cima</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="387"/>
        <source>Move up the selected items</source>
        <translation>Sposta elementi selezionati in sù</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="413"/>
        <source>Move down the selected items</source>
        <translation>Sposta elementi selezionati in giù</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="439"/>
        <source>Move the selected items to the bottom</source>
        <translation>Metti elementi selezionati in coda</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="465"/>
        <source>Add file/folder</source>
        <translation>Aggiungi file/cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="494"/>
        <source>Delete the selected items</source>
        <translation>Elimina elementi selezionati</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="520"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="549"/>
        <source>Export the transfer list</source>
        <translation>Esporta lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="575"/>
        <source>Import the transfer list</source>
        <translation>Importa lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="630"/>
        <source>Previous</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="637"/>
        <source>Next</source>
        <translation>Successivo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="672"/>
        <location filename="../../interface.ui" line="741"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="692"/>
        <source>Export the errors into transfer list</source>
        <translation>Esporta errori in lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="731"/>
        <source>Source</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="736"/>
        <source>Destination</source>
        <translation>Destinazione</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="750"/>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Add file</source>
        <translation>Aggiungi file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Add folder</source>
        <translation>Aggiungi cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Move file(s)</source>
        <translation>Spostare file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Move folder</source>
        <translation>Spostare cartella/e</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="832"/>
        <source>Copy file(s)</source>
        <translation>Copiare file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="841"/>
        <source>Copy folder</source>
        <translation>Copiare cartella/e</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="267"/>
        <source>Show dual progression</source>
        <translation>Mostrare progressione duale</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Mostrare velocità come informazione principale</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Funzionalità</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Avvio con bottone &quot;Avanzate&quot; premuto</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Alla chiusura riduci nell&apos;area di notifica</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>A fine copia</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Limitare velocità di copia a</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation>Avvia ridotto a icona</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="306"/>
        <source>Click to edit the color</source>
        <translation>Cliccare per modificare colore</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation>Salva posizione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Informations</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Visualizzazione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="257"/>
        <source>Speed with progress bar</source>
        <translation>Velocità in barra progresso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="287"/>
        <source>Progression color</source>
        <translation>Colore progressione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Show progression in the title</source>
        <translation>Mostra percentuale di progresso nel titolo</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Sempre in primo piano</translation>
    </message>
</context>
</TS>

==> ultracopier_2.2.6.0.orig.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/it/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="341"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Acquista versione Ultimate per finanziare lo sviluppo</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="341"/>
        <source>Register your key</source>
        <translation>Registrate la vostra chiave</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="440"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>File %1/%2, dimensione: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="674"/>
        <source>Copy list</source>
        <translation>Lista di copia</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="676"/>
        <source>Move list</source>
        <translation>Lista di spostamento</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1117"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Non chiudere se vengono rilevati errori</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1118"/>
        <source>Never close</source>
        <translation>Non chiudere mai</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1119"/>
        <source>Always close</source>
        <translation>Chiudi sempre</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1121"/>
        <source>File Name, 0KB</source>
        <translation>Nome file, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1395"/>
        <location filename="../../interface.cpp" line="1407"/>
        <location filename="../../interface.cpp" line="1419"/>
        <source>Select a color</source>
        <translation>Seleziona colore</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1494"/>
        <location filename="../../interface.cpp" line="1498"/>
        <location filename="../../interface.cpp" line="1500"/>
        <source>%1 %2% of %3</source>
        <translation>%1 %2% di %3</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="294"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Non chiudere se vengono rilevati errori</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="295"/>
        <source>Never close</source>
        <translation>Non chiudere mai</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="296"/>
        <source>Always close</source>
        <translation>Chiudi sempre</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="510"/>
        <location filename="../../ThemesFactory.cpp" line="525"/>
        <location filename="../../ThemesFactory.cpp" line="540"/>
        <source>Select a color</source>
        <translation>Seleziona colore</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>From:</source>
        <translation>Da:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="74"/>
        <source>To:</source>
        <translation>A:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="235"/>
        <source>&amp;More</source>
        <translation>&amp;Altro</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="255"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="269"/>
        <source>&amp;Skip</source>
        <translation>&amp;Salta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="280"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="127"/>
        <source>Close on transfer completion</source>
        <translation>Chiudi a trasferimento completato</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="295"/>
        <source>Limit copy speed to:</source>
        <translation>Limitare velocità di copia a:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="338"/>
        <source>Transfer list</source>
        <translation>Lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="361"/>
        <source>Move the selected items to the top</source>
        <translation>Sposta elementi selezionati in cima</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="387"/>
        <source>Move up the selected items</source>
        <translation>Sposta in su gli elementi selezionati</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="413"/>
        <source>Move down the selected items</source>
        <translation>Sposta in giù gli elementi selezionati</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="439"/>
        <source>Move the selected items to the bottom</source>
        <translation>Sposta elementi selezionati in fondo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="465"/>
        <source>Add file/folder</source>
        <translation>Aggiungi file/cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="494"/>
        <source>Delete the selected items</source>
        <translation>Elimina gli elementi selezionati</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="520"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="549"/>
        <source>Export the transfer list</source>
        <translation>Esporta lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="575"/>
        <source>Import the transfer list</source>
        <translation>Importa lista di trasferimento</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="630"/>
        <source>Previous</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="637"/>
        <source>Next</source>
        <translation>Successivo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="672"/>
        <location filename="../../interface.ui" line="741"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="692"/>
        <source>Export the errors into transfer list</source>
        <translation>Esporta nella lista di trasferimento gli errori</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="731"/>
        <source>Source</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="736"/>
        <source>Destination</source>
        <translation>Destinazione</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="750"/>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Add file</source>
        <translation>Aggiungi file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Add folder</source>
        <translation>Aggiungi cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Move file(s)</source>
        <translation>Sposta (i) file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Move folder</source>
        <translation>Sposta cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="832"/>
        <source>Copy file(s)</source>
        <translation>Copia (i) file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="841"/>
        <source>Copy folder</source>
        <translation>Copia cartella</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="402"/>
        <source>Show dual progression</source>
        <translation>Visualizza progressione duale</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Mostrare velocità come informazione principale</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Utilizza</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Avvia con pulsante &quot;Altro&quot; attivo</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Alla chiusura riduci nell&apos;area di notifica</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>A fine copia</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Limitare velocità di copia a</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation>Avvia ridotto a icona</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="269"/>
        <source>Click to edit the color</source>
        <translation>Cliccare per modificare colore</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation>Salva posizione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Visualizzazione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="368"/>
        <source>Speed with progress bar</source>
        <translation>Velocità nella barra di progresso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="378"/>
        <source>Progression color</source>
        <translation>Colore progressione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="388"/>
        <source>Show progression in the title</source>
        <translation>Visualizza progresso nel titolo</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="395"/>
        <source>General margin</source>
        <translation>Margine generale</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="425"/>
        <source>General spacing</source>
        <translation>Spaziatura generale</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Sempre in primo piano</translation>
    </message>
</context>
</TS>
